package org.acme.getting.started;

import io.quarkus.security.identity.SecurityIdentity;
import org.jboss.logging.Logger;

import javax.inject.Inject;
import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptor;
import javax.interceptor.InvocationContext;
import java.util.Optional;

@Logged
@Interceptor
public class LoggedInterceptor {

    private static final Logger LOGGER = Logger.getLogger(LoggedInterceptor.class);

    @Inject
    SecurityIdentity identity;

    @AroundInvoke
    public Object logSomeValue(InvocationContext context) throws Exception {
        LOGGER.info("LoggedInterceptor called");
        Optional.ofNullable(context)
                .map(InvocationContext::getMethod)
                .map(it -> it.getAnnotation(Logged.class))
                .map(Logged::value)
                .ifPresentOrElse(
                        it -> LOGGER.info("LoggedInterceptor found @Logged annotation with value " + it),
                        () -> LOGGER.warn("LoggedInterceptor found no @Logged annotation with a value")
                );

        return context.proceed();
    }
}
